//
//  MapViewController.swift
//  modalview
//
//  Created by kunii on 2017/10/30.
//  Copyright © 2017年 Takahiro Kunii. All rights reserved.
//

import UIKit

//  デリゲートが持っているべきメソッドをプロトコルで定義
@objc protocol MapViewControllerDelegate {
    func selectDestination(name:String)
}

class MapViewController: UIViewController {
    //  デリゲートの型は上記のプロトコルとする
    weak var delegate:MapViewControllerDelegate?
    
    //  ストーリーボードから設定
    @IBOutlet var mapView:MapView!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        mapView.subview.image = UIImage(named:"map")
        let swipeGestureRecognizer = UISwipeGestureRecognizer(target: self, action: #selector(swipe))
        swipeGestureRecognizer.direction = .down
        swipeGestureRecognizer.requiresExclusiveTouchType = true
        self.view.addGestureRecognizer(swipeGestureRecognizer)

        //  タップ用追加
        let tapGestureRecognizer = UITapGestureRecognizer(target: self, action: #selector(tap))
        self.view.addGestureRecognizer(tapGestureRecognizer)
    }

    @objc func swipe() {
        self.dismiss(animated: true, completion: nil)
    }

    @objc func tap(tapGestureRecognizer:UITapGestureRecognizer) {
        let location = tapGestureRecognizer.location(in: self.view)
        self.delegate?.selectDestination(name:"\(location)")
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

}
